var group___p_c_z_scene_manager =
[
    [ "Ogre::Capsule", "class_ogre_1_1_capsule.html", [
      [ "Capsule", "class_ogre_1_1_capsule.html#a56c3c5b36e83fc62b143ed8091bc7f3b", null ],
      [ "Capsule", "class_ogre_1_1_capsule.html#afc5e0517c27499734169232bd9a71eb4", null ],
      [ "set", "class_ogre_1_1_capsule.html#a1393e223b4ea3a419012c0d9dfc67caa", null ],
      [ "setOrigin", "class_ogre_1_1_capsule.html#ac2a8d71fa6bc0e1ebca688908811a008", null ],
      [ "setEndPoint", "class_ogre_1_1_capsule.html#a29b55ae0127e3d397feaa072fb92a2be", null ],
      [ "setRadius", "class_ogre_1_1_capsule.html#aace6ae7d91d348fc57862b13dd5ab588", null ],
      [ "intersects", "class_ogre_1_1_capsule.html#ac136bc82a1182d6e8fc28334301c9242", null ],
      [ "intersects", "class_ogre_1_1_capsule.html#aa4187d8396fcaea692198918cc2a466d", null ],
      [ "mSegment", "class_ogre_1_1_capsule.html#aab9f2941bf16966267a284799bf2ba3b", null ],
      [ "mRadius", "class_ogre_1_1_capsule.html#a0393c543b42873cf8eefd29cad40a43a", null ]
    ] ],
    [ "Ogre::PCPlane", "class_ogre_1_1_p_c_plane.html", [
      [ "PCPlane", "class_ogre_1_1_p_c_plane.html#a2472dfd80725c2e84b5ef7baa4384c2e", null ],
      [ "PCPlane", "class_ogre_1_1_p_c_plane.html#a0b88208979cd8ccffd4d91bb8373549f", null ],
      [ "PCPlane", "class_ogre_1_1_p_c_plane.html#ad3eff30e9736cc380facaa825306dbf2", null ],
      [ "PCPlane", "class_ogre_1_1_p_c_plane.html#a060064e403c405d075786f043bcd37e8", null ],
      [ "~PCPlane", "class_ogre_1_1_p_c_plane.html#a6f42638ed66e7661b8b911861fc67b64", null ],
      [ "setFromOgrePlane", "class_ogre_1_1_p_c_plane.html#a09ed045de29ff480bfaaf8d35549f3b5", null ],
      [ "getPortal", "class_ogre_1_1_p_c_plane.html#a6c3b96183263285bbb9fcc239b411467", null ],
      [ "setPortal", "class_ogre_1_1_p_c_plane.html#a6b3f83e82290b617368501cab3c1919a", null ]
    ] ],
    [ "Ogre::PCZCamera", "class_ogre_1_1_p_c_z_camera.html", [
      [ "Visibility", "class_ogre_1_1_p_c_z_camera.html#ad669588c56898a61e73eb2ab41f0c91c", [
        [ "NONE", "class_ogre_1_1_p_c_z_camera.html#ad669588c56898a61e73eb2ab41f0c91caa4263bb28fbff0eb02b13279b1da0907", null ],
        [ "PARTIAL", "class_ogre_1_1_p_c_z_camera.html#ad669588c56898a61e73eb2ab41f0c91cada3901a8eefd37fdf9e6aabb614142ba", null ],
        [ "FULL", "class_ogre_1_1_p_c_z_camera.html#ad669588c56898a61e73eb2ab41f0c91ca0eb5e5fe99cae8c9608e1e197baa1ab5", null ]
      ] ],
      [ "PCZCamera", "class_ogre_1_1_p_c_z_camera.html#a203af6f72ce379e5f2a9469295187b7a", null ],
      [ "~PCZCamera", "class_ogre_1_1_p_c_z_camera.html#aee4e5b88dbe20f0a6f03618135fabde7", null ],
      [ "getBoundingBox", "class_ogre_1_1_p_c_z_camera.html#abd7e041206e4f36453e784b531b290c6", null ],
      [ "isVisible", "class_ogre_1_1_p_c_z_camera.html#aa5e5ee66154a6c17804b52f1b1bc0a34", null ],
      [ "isVisible", "class_ogre_1_1_p_c_z_camera.html#a6f359238ef68a2175bd799bc2bf28030", null ],
      [ "isVisibile", "class_ogre_1_1_p_c_z_camera.html#a0a3632521a6f13e53b4bf1a8d006fb2e", null ],
      [ "getVisibility", "class_ogre_1_1_p_c_z_camera.html#aec5f399a2b78457c1ca0bb22b95efef9", null ],
      [ "setProjectionType", "class_ogre_1_1_p_c_z_camera.html#a9cc849a0862bb9ce23f7b7818ac64f7e", null ],
      [ "update", "class_ogre_1_1_p_c_z_camera.html#ac5d8ae8e58bed364960665fb02cf8675", null ],
      [ "addPortalCullingPlanes", "class_ogre_1_1_p_c_z_camera.html#afbacdc365ba31e1d3ace59928a338a7e", null ],
      [ "removePortalCullingPlanes", "class_ogre_1_1_p_c_z_camera.html#a4996a6818399957261493cb8a7646581", null ],
      [ "removeAllExtraCullingPlanes", "class_ogre_1_1_p_c_z_camera.html#a8e435d5fb8d519dbfcc34508c3ec88c0", null ]
    ] ],
    [ "Ogre::PCZFrustum", "class_ogre_1_1_p_c_z_frustum.html", [
      [ "Visibility", "class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0", [
        [ "NONE", "class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0abd7c5a5255321386e7068e5da5f1e497", null ],
        [ "PARTIAL", "class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0a80f7e32f2ff9beaa89ca2f2a3005f784", null ],
        [ "FULL", "class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0ac8d449ff26f6e8000ec3f5571d13b66f", null ]
      ] ],
      [ "PCZFrustum", "class_ogre_1_1_p_c_z_frustum.html#a8a7ebf11b58dea6d550e107d42067436", null ],
      [ "~PCZFrustum", "class_ogre_1_1_p_c_z_frustum.html#aa2f491448874e2c406d7c6eea2acb87e", null ],
      [ "isVisible", "class_ogre_1_1_p_c_z_frustum.html#abc51c9cb3798768f1c1011411be217e7", null ],
      [ "isVisible", "class_ogre_1_1_p_c_z_frustum.html#afe12561a64afee6006c19ca1f6b763e6", null ],
      [ "isVisible", "class_ogre_1_1_p_c_z_frustum.html#aa7bcb920cac2f626ae456b529286eab2", null ],
      [ "isFullyVisible", "class_ogre_1_1_p_c_z_frustum.html#a766c4d803c77d409eafcd54ea98837c7", null ],
      [ "isFullyVisible", "class_ogre_1_1_p_c_z_frustum.html#accbb31c158eb7f299e6a364d9e1f81c5", null ],
      [ "isFullyVisible", "class_ogre_1_1_p_c_z_frustum.html#a64bb361f08dd87c869c0db1a6e1f0171", null ],
      [ "getVisibility", "class_ogre_1_1_p_c_z_frustum.html#a80703cbea15bbe558c6ef9bec77cb592", null ],
      [ "addPortalCullingPlanes", "class_ogre_1_1_p_c_z_frustum.html#addbc896267412ef5876bdf7dc842abee", null ],
      [ "removePortalCullingPlanes", "class_ogre_1_1_p_c_z_frustum.html#a61828636609ee20ed7edbcdd57e4b504", null ],
      [ "removeAllCullingPlanes", "class_ogre_1_1_p_c_z_frustum.html#a4628345ecaf33b67b7526a3a9ee22e71", null ],
      [ "setOrigin", "class_ogre_1_1_p_c_z_frustum.html#a31654e4753c0e8c85d455da625b9f4fe", null ],
      [ "setOriginPlane", "class_ogre_1_1_p_c_z_frustum.html#ad89a86104eae899243a20ac5853bed05", null ],
      [ "setUseOriginPlane", "class_ogre_1_1_p_c_z_frustum.html#a84738d07b1001be10a5628870c55ae55", null ],
      [ "getUnusedCullingPlane", "class_ogre_1_1_p_c_z_frustum.html#a55821bc94a9416e2e1728ea4dbaea9d6", null ],
      [ "setProjectionType", "class_ogre_1_1_p_c_z_frustum.html#aecf0bf5650137366f3c5b9cf7ae6ff24", null ],
      [ "getProjectionType", "class_ogre_1_1_p_c_z_frustum.html#a1287ee86eabacb01d8af392c15015435", null ]
    ] ],
    [ "Ogre::PCZLight", "class_ogre_1_1_p_c_z_light.html", [
      [ "PCZLight", "class_ogre_1_1_p_c_z_light.html#ae62ec9e9fa36ca2c6072c8e08ddfaa4b", null ],
      [ "PCZLight", "class_ogre_1_1_p_c_z_light.html#a811b285754f1f752968a1cc0ddde3115", null ],
      [ "~PCZLight", "class_ogre_1_1_p_c_z_light.html#a7251ee6bfb370a5629da7aaa654b5485", null ],
      [ "getMovableType", "class_ogre_1_1_p_c_z_light.html#a4c6cf65608fffdb5e5f9c1c4bb067502", null ],
      [ "clearAffectedZones", "class_ogre_1_1_p_c_z_light.html#a4b128f16ec323ba495e9373da4800f2a", null ],
      [ "addZoneToAffectedZonesList", "class_ogre_1_1_p_c_z_light.html#a0d7d0bcc9aad97228ef7e40e41f7c7b6", null ],
      [ "affectsZone", "class_ogre_1_1_p_c_z_light.html#adfed7af8998a6ad31130820527476b37", null ],
      [ "affectsVisibleZone", "class_ogre_1_1_p_c_z_light.html#a8a586f51c15661e78c876d2b6e04c3b7", null ],
      [ "setAffectsVisibleZone", "class_ogre_1_1_p_c_z_light.html#a41d865602a231b36ead55d751f4cd77d", null ],
      [ "updateZones", "class_ogre_1_1_p_c_z_light.html#a4830347df6db80de75f2054c3c1b647e", null ],
      [ "removeZoneFromAffectedZonesList", "class_ogre_1_1_p_c_z_light.html#ab0c63d9303a53d4fb735e11e0fac3f09", null ],
      [ "_notifyMoved", "class_ogre_1_1_p_c_z_light.html#ace6354632ef1c4c809d0e01711f2b8dc", null ],
      [ "clearNeedsUpdate", "class_ogre_1_1_p_c_z_light.html#a017e849f6d4adcffba153f80d9c8bbe6", null ],
      [ "getNeedsUpdate", "class_ogre_1_1_p_c_z_light.html#a2565a8e8a9ef516800ab6514dce61055", null ]
    ] ],
    [ "Ogre::PCZLightFactory", "class_ogre_1_1_p_c_z_light_factory.html", [
      [ "PCZLightFactory", "class_ogre_1_1_p_c_z_light_factory.html#a2c58d971af884e88775f8cf46fe7e75a", null ],
      [ "~PCZLightFactory", "class_ogre_1_1_p_c_z_light_factory.html#a7512e363b4db3fd110fe4307fd5c16e8", null ],
      [ "getType", "class_ogre_1_1_p_c_z_light_factory.html#a18b0d8505e778e57f04d965da62664e9", null ],
      [ "FACTORY_TYPE_NAME", "class_ogre_1_1_p_c_z_light_factory.html#ae943f1e7527419df075c47299e9c99cd", null ]
    ] ],
    [ "Ogre::PCZone", "class_ogre_1_1_p_c_zone.html", [
      [ "NODE_LIST_TYPE", "class_ogre_1_1_p_c_zone.html#a56cfd6d3c1d59fe4b05e6755dcab51c9", [
        [ "HOME_NODE_LIST", "class_ogre_1_1_p_c_zone.html#a56cfd6d3c1d59fe4b05e6755dcab51c9ad2e170349cb0831b4ce3b48b1ae27f9e", null ],
        [ "VISITOR_NODE_LIST", "class_ogre_1_1_p_c_zone.html#a56cfd6d3c1d59fe4b05e6755dcab51c9ae8fe0f46d6cf9492ed9ca5ed37c4ac8a", null ]
      ] ],
      [ "PCZone", "class_ogre_1_1_p_c_zone.html#a134420c2b9ac23362da7a824a8a93a52", null ],
      [ "~PCZone", "class_ogre_1_1_p_c_zone.html#a4b03efaddf72d4a686e6a4b324f8e012", null ],
      [ "getZoneTypeName", "class_ogre_1_1_p_c_zone.html#a68896ad51925741faa4ddf28f6bddc5f", null ],
      [ "getName", "class_ogre_1_1_p_c_zone.html#ae4fbfcc16340e4624692a434ead9cb5a", null ],
      [ "getEnclosureNode", "class_ogre_1_1_p_c_zone.html#a7f07aec25c232cc98801eb927da4308a", null ],
      [ "setHasSky", "class_ogre_1_1_p_c_zone.html#a8ff931ac282027f2d1d786b128a92a94", null ],
      [ "hasSky", "class_ogre_1_1_p_c_zone.html#a6d4dc7bac6baf6dfc3c41ded5a9d373a", null ],
      [ "setLastVisibleFrame", "class_ogre_1_1_p_c_zone.html#aa89fe9c71d0e86e61d70ea5684cc83d2", null ],
      [ "getLastVisibleFrame", "class_ogre_1_1_p_c_zone.html#ac1fa831a0caf1f7defd52047322434f0", null ],
      [ "setLastVisibleFromCamera", "class_ogre_1_1_p_c_zone.html#ada07deb5c12753fb1bf81d5d92a1e912", null ],
      [ "getLastVisibleFromCamera", "class_ogre_1_1_p_c_zone.html#a34886e1892df8103abd009e9fd4985e7", null ],
      [ "setEnclosureNode", "class_ogre_1_1_p_c_zone.html#ab2d35654e2d9c545f3cdbc8e42805952", null ],
      [ "_addNode", "class_ogre_1_1_p_c_zone.html#abe6d8190b3af0e21bc21f39992c27b3c", null ],
      [ "removeNode", "class_ogre_1_1_p_c_zone.html#a4fa8f4efd6a105c2aa49635518c647a0", null ],
      [ "_clearNodeLists", "class_ogre_1_1_p_c_zone.html#acfc4de41d78f2a75d3a569e26196a5fe", null ],
      [ "requiresZoneSpecificNodeData", "class_ogre_1_1_p_c_zone.html#ac1410aa91be196fad3f862de5a710644", null ],
      [ "createNodeZoneData", "class_ogre_1_1_p_c_zone.html#ae9210b537407fadb23e46c30fd884d9a", null ],
      [ "findMatchingPortal", "class_ogre_1_1_p_c_zone.html#a1e1d71f12030a9d3333a22a33edebaa1", null ],
      [ "_addPortal", "class_ogre_1_1_p_c_zone.html#accc5449350478d04f943d3a313704198", null ],
      [ "_removePortal", "class_ogre_1_1_p_c_zone.html#aae81008aaba331d75d78ce12f741acf4", null ],
      [ "_addAntiPortal", "class_ogre_1_1_p_c_zone.html#ad1cc272698022165a64f85b5e6669917", null ],
      [ "_removeAntiPortal", "class_ogre_1_1_p_c_zone.html#aa1b0c4809cffb26dd257dd82c97adee8", null ],
      [ "_checkNodeAgainstPortals", "class_ogre_1_1_p_c_zone.html#afffceda4722bddf44acdab10cd95ad52", null ],
      [ "_checkLightAgainstPortals", "class_ogre_1_1_p_c_zone.html#a917bd0e1990d568acdb9e8fb1e75492a", null ],
      [ "updatePortalsZoneData", "class_ogre_1_1_p_c_zone.html#aef88f09e45e94145c19932a77f491dfe", null ],
      [ "dirtyNodeByMovingPortals", "class_ogre_1_1_p_c_zone.html#a053576e1866ba02ec96b51b1f46854ee", null ],
      [ "updateNodeHomeZone", "class_ogre_1_1_p_c_zone.html#a62b82f06b8f6118960c9a7748f030275", null ],
      [ "findVisibleNodes", "class_ogre_1_1_p_c_zone.html#a602b3631ccb95e2bdd67fbc80aa1355e", null ],
      [ "_findNodes", "class_ogre_1_1_p_c_zone.html#ac6d95f1d9e814b380b99b266ac2a9383", null ],
      [ "_findNodes", "class_ogre_1_1_p_c_zone.html#a4c5965d7fb2b0fdcc0bb539d5cd52a8d", null ],
      [ "_findNodes", "class_ogre_1_1_p_c_zone.html#a70ffd8f5e9a3a68926672a2276f854bb", null ],
      [ "_findNodes", "class_ogre_1_1_p_c_zone.html#a97dd8130b4c89ac85d726f5bf2f328a4", null ],
      [ "setOption", "class_ogre_1_1_p_c_zone.html#a392214a159e92805364bff307bbf0549", null ],
      [ "notifyCameraCreated", "class_ogre_1_1_p_c_zone.html#a7f211fdbe1e7b34e64671c8ef11e58d7", null ],
      [ "notifyWorldGeometryRenderQueue", "class_ogre_1_1_p_c_zone.html#a127fceccd44fb4c49a503edceb054623", null ],
      [ "notifyBeginRenderScene", "class_ogre_1_1_p_c_zone.html#abe5422e04a4806283ce1716808b53346", null ],
      [ "setZoneGeometry", "class_ogre_1_1_p_c_zone.html#a6101e456713f4f75910c0e9b40d5f8b0", null ],
      [ "getAABB", "class_ogre_1_1_p_c_zone.html#ac4955afa0014db1b4ab2a8aa3745f99e", null ],
      [ "setPortalsUpdated", "class_ogre_1_1_p_c_zone.html#ada5403814b6ba8a1284e80ab97d08f71", null ],
      [ "getPortalsUpdated", "class_ogre_1_1_p_c_zone.html#aa1363a02d2cf5526fb11c86b836707d1", null ],
      [ "getUserData", "class_ogre_1_1_p_c_zone.html#aad5502f5ffe0752c1a9f525ea2d536e0", null ],
      [ "setUserData", "class_ogre_1_1_p_c_zone.html#abc8ebac2f46f22bb525856ec91be771e", null ],
      [ "mPortals", "class_ogre_1_1_p_c_zone.html#a3f2f62ba44ece0239408e0e8e04e0a72", null ],
      [ "mAntiPortals", "class_ogre_1_1_p_c_zone.html#abf2c82ac1e74ccd3852d3a332a8c4c99", null ],
      [ "mPCZSM", "class_ogre_1_1_p_c_zone.html#a93e8f7a50cdea269e209fd15f87c557d", null ]
    ] ],
    [ "Ogre::PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html", [
      [ "ZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#a44d7ec7900f22ea1a1dcaf62bbe65735", null ],
      [ "PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html#ac6e44e60f66e1540d4c14a52aa36120c", null ],
      [ "~PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html#a6caa6bf780a9dd066385a14c68d1d8f2", null ],
      [ "getTypeName", "class_ogre_1_1_p_c_z_scene_manager.html#a4692cc30266e489209f652ae2fce2eff", null ],
      [ "init", "class_ogre_1_1_p_c_z_scene_manager.html#a93564bf4242ff46afd5bac6eb908fb4b", null ],
      [ "createPortal", "class_ogre_1_1_p_c_z_scene_manager.html#aa1bbab893e1482645607f7aa0985112e", null ],
      [ "destroyPortal", "class_ogre_1_1_p_c_z_scene_manager.html#a97e82454f91110f27d08f4873eec2c5b", null ],
      [ "destroyPortal", "class_ogre_1_1_p_c_z_scene_manager.html#a86eb45d2d1683ec340cf91c4a7b742e0", null ],
      [ "createAntiPortal", "class_ogre_1_1_p_c_z_scene_manager.html#ac4ba4071cdffd0a50cbeeb49d69c09d6", null ],
      [ "destroyAntiPortal", "class_ogre_1_1_p_c_z_scene_manager.html#a280141a83b4880d0fbe929ab8685ab89", null ],
      [ "destroyAntiPortal", "class_ogre_1_1_p_c_z_scene_manager.html#a2015c3a1cb4b671de561bd124739a131", null ],
      [ "createZoneFromFile", "class_ogre_1_1_p_c_z_scene_manager.html#a7a07bfff9ae16ff65ee6da16cfdeaa25", null ],
      [ "setZoneGeometry", "class_ogre_1_1_p_c_z_scene_manager.html#a1d81a09d8ddbd08f4cbbd2fd74b121ab", null ],
      [ "createSceneNodeImpl", "class_ogre_1_1_p_c_z_scene_manager.html#abdad18e34d3fb9ac355bfa186726f4c1", null ],
      [ "createSceneNodeImpl", "class_ogre_1_1_p_c_z_scene_manager.html#ae16b9aad2c729ecf643ee4befa2c1299", null ],
      [ "createCamera", "class_ogre_1_1_p_c_z_scene_manager.html#a54678fa02c98f4b336c789f5b59720ea", null ],
      [ "destroySceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a92a76aaee441c37b02eefe5291818d56", null ],
      [ "clearScene", "class_ogre_1_1_p_c_z_scene_manager.html#a91a18704ec2eb46ba4910cb39c43662d", null ],
      [ "setWorldGeometryRenderQueue", "class_ogre_1_1_p_c_z_scene_manager.html#a222a1701e1a9453b0143ea9a0076cca0", null ],
      [ "_renderScene", "class_ogre_1_1_p_c_z_scene_manager.html#a8fe6aa9f9cd27ca47969edb121846f27", null ],
      [ "enableSky", "class_ogre_1_1_p_c_z_scene_manager.html#a6f01db5bc19df9229e7ceb6c01b06dfa", null ],
      [ "setSkyZone", "class_ogre_1_1_p_c_z_scene_manager.html#aab8c479c11d401a917e3471fbfc49bfe", null ],
      [ "_updateSceneGraph", "class_ogre_1_1_p_c_z_scene_manager.html#a2422a7d20a51b0ce63b16b8549cc5bf3", null ],
      [ "_findVisibleObjects", "class_ogre_1_1_p_c_z_scene_manager.html#afea89abce2823af9c60eac169e6c643c", null ],
      [ "createLight", "class_ogre_1_1_p_c_z_scene_manager.html#a56cf001fd734e8cc410d77f758d269f3", null ],
      [ "getLight", "class_ogre_1_1_p_c_z_scene_manager.html#a9f0834156627c57d1ca3aa2546119a9c", null ],
      [ "hasLight", "class_ogre_1_1_p_c_z_scene_manager.html#a1a3d1b6287f99d0a2d4e533a481bdd47", null ],
      [ "destroyLight", "class_ogre_1_1_p_c_z_scene_manager.html#aee2ad35c6d3e4aef9fe6f9fff897264b", null ],
      [ "destroyAllLights", "class_ogre_1_1_p_c_z_scene_manager.html#a46e55cdda71917942ac615491d65b027", null ],
      [ "_updatePortalZoneData", "class_ogre_1_1_p_c_z_scene_manager.html#a12ec71ae075484bcdee518bbecfcdf42", null ],
      [ "_dirtyNodeByMovingPortals", "class_ogre_1_1_p_c_z_scene_manager.html#a3ba0b3c24201c909927ece0792ea2cc7", null ],
      [ "_updatePCZSceneNodes", "class_ogre_1_1_p_c_z_scene_manager.html#a2bdd0173a377fdb56d51a52467bd5856", null ],
      [ "_calcZonesAffectedByLights", "class_ogre_1_1_p_c_z_scene_manager.html#adf66f55d76d25dbeeb91c1cc17f049bc", null ],
      [ "connectPortalsToTargetZonesByLocation", "class_ogre_1_1_p_c_z_scene_manager.html#a1f4404d5bea854e1561cdbb6f835e828", null ],
      [ "_updatePCZSceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#aebefaaad96e5a85efb54ff10b6f25c34", null ],
      [ "removeSceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a95e397bc019476f1d2512c169ff466c5", null ],
      [ "addPCZSceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#ac08eaf17e10fc0808d548c5e630efc31", null ],
      [ "createZone", "class_ogre_1_1_p_c_z_scene_manager.html#a8438b2e572e58dd0c12433b7bf2f43a1", null ],
      [ "destroyZone", "class_ogre_1_1_p_c_z_scene_manager.html#a735631ef8e17d477e2e9b3f7abd29bd8", null ],
      [ "_updateHomeZone", "class_ogre_1_1_p_c_z_scene_manager.html#a14a412b3101c6e8e8d9317235b1d2d93", null ],
      [ "findZoneForPoint", "class_ogre_1_1_p_c_z_scene_manager.html#a7858690b21eaad51929e3c02086a17ca", null ],
      [ "createZoneSpecificNodeData", "class_ogre_1_1_p_c_z_scene_manager.html#ae1effa6fe8a1d7aacfb4ed9b3c727e67", null ],
      [ "createZoneSpecificNodeData", "class_ogre_1_1_p_c_z_scene_manager.html#aed6cdaf5634e5632d0e8bac5e1ba76d1", null ],
      [ "setNodeHomeZone", "class_ogre_1_1_p_c_z_scene_manager.html#aa8ca4ec46bc35211f8307b22408c5486", null ],
      [ "findNodesIn", "class_ogre_1_1_p_c_z_scene_manager.html#a70ac27e437a9785222c2b2c0be865e05", null ],
      [ "findNodesIn", "class_ogre_1_1_p_c_z_scene_manager.html#a0d0e8fece331960d1d81adb188797c52", null ],
      [ "findNodesIn", "class_ogre_1_1_p_c_z_scene_manager.html#a668021ea89d4b496f982b0caa5023a08", null ],
      [ "findNodesIn", "class_ogre_1_1_p_c_z_scene_manager.html#a74a9c8bc3aad0a7dc95cca3c0fd5cfa6", null ],
      [ "getDefaultZone", "class_ogre_1_1_p_c_z_scene_manager.html#a37b710d37afd14f1a028bdb9dd26151e", null ],
      [ "getZoneByName", "class_ogre_1_1_p_c_z_scene_manager.html#a53d963984aefa442b6c9dc20c9a34f4a", null ],
      [ "setShowPortals", "class_ogre_1_1_p_c_z_scene_manager.html#a25cba02e4766d9511b03684295ce73c7", null ],
      [ "setOption", "class_ogre_1_1_p_c_z_scene_manager.html#a147e7252e3cd19ad9c09e0a02e9b3a44", null ],
      [ "getOption", "class_ogre_1_1_p_c_z_scene_manager.html#ada9a794e741792754ec78b0cb89e7a9c", null ],
      [ "getOptionValues", "class_ogre_1_1_p_c_z_scene_manager.html#ac24f28929b4e0ea49e4c7dac9f11c9c3", null ],
      [ "getOptionKeys", "class_ogre_1_1_p_c_z_scene_manager.html#ac77f8127d6709de6858dbc991de7c3ef", null ],
      [ "createAABBQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a315e2001409ef99dbdba24ef9d4c684f", null ],
      [ "createSphereQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a3e1592ab984057791b468b0c1a538f48", null ],
      [ "createPlaneBoundedVolumeQuery", "class_ogre_1_1_p_c_z_scene_manager.html#ab3cb3c5dda5c4779ecc7b3acd1b0189f", null ],
      [ "createRayQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a3c5eea51ce8ea204bbbc786a8df311c0", null ],
      [ "createIntersectionQuery", "class_ogre_1_1_p_c_z_scene_manager.html#aa194a8264693295fcbcdd14b9e8d325c", null ],
      [ "getZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#ad8c3bdeb482268348587406720128530", null ],
      [ "_clearAllZonesPortalUpdateFlag", "class_ogre_1_1_p_c_z_scene_manager.html#a6b5ba29779d8d03ac92b65bd21ea615d", null ],
      [ "updateShadowTextures", "class_ogre_1_1_p_c_z_scene_manager.html#a47c37999f434fe7e788762159d06d670", null ],
      [ "PCZIntersectionSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a66e03b2e49e35a0f0d2b6795855e5f20", null ],
      [ "PCZRaySceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#ae08bc00b90e82c22fd5281b87c0c76f4", null ],
      [ "PCZSphereSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a0f46ad3758026a3cefff77b8313fb084", null ],
      [ "PCZAxisAlignedBoxSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#aeee8eae390ce0557ba886e5c3166e50d", null ],
      [ "PCZPlaneBoundedVolumeListSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a7ad4f1ee5e2004e94292aaa8ea5a0bc1", null ]
    ] ],
    [ "Ogre::PCZSceneManagerFactory", "class_ogre_1_1_p_c_z_scene_manager_factory.html", [
      [ "createInstance", "class_ogre_1_1_p_c_z_scene_manager_factory.html#ab602b191fcbf40251b8e890021028c36", null ],
      [ "getTypeName", "class_ogre_1_1_p_c_z_scene_manager_factory.html#afc193bcbd152dcdfa20423937a01b6a3", null ],
      [ "FACTORY_TYPE_NAME", "class_ogre_1_1_p_c_z_scene_manager_factory.html#ac1149fd3168410fdedf4c09c1deb85d1", null ]
    ] ],
    [ "Ogre::PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html", [
      [ "PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a28325ac8e36f3ad4063670b6f0e0078a", null ],
      [ "PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a6d29c74d3792328118cafe867445287d", null ],
      [ "~PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a9cb1ec437e14d283253a49ece7c9c144", null ],
      [ "_update", "class_ogre_1_1_p_c_z_scene_node.html#afdf56660f1aee5a3e0104ad40b059e34", null ],
      [ "updateFromParentImpl", "class_ogre_1_1_p_c_z_scene_node.html#ad3b9cbbd7c0c4ff4b149840599946b6b", null ],
      [ "createChildSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a020b91598e30fc8591130b7e15a7c729", null ],
      [ "createChildSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a3bb49869d0cb70b720113103a2c77d7b", null ],
      [ "getHomeZone", "class_ogre_1_1_p_c_z_scene_node.html#a27733c2fae1da581743dd406e6910a9e", null ],
      [ "setHomeZone", "class_ogre_1_1_p_c_z_scene_node.html#a4140b9d947495de466ed24d2ac355a54", null ],
      [ "anchorToHomeZone", "class_ogre_1_1_p_c_z_scene_node.html#a57893d37be2e8694c9a1cc6ca41b929d", null ],
      [ "isAnchored", "class_ogre_1_1_p_c_z_scene_node.html#ab4e60bb8dacc17473466661cd7da4b13", null ],
      [ "allowToVisit", "class_ogre_1_1_p_c_z_scene_node.html#a0aa077976dc66f8958bb4126aec7818e", null ],
      [ "allowedToVisit", "class_ogre_1_1_p_c_z_scene_node.html#a2c91f1000535fd11c872b93d43917dc5", null ],
      [ "addZoneToVisitingZonesMap", "class_ogre_1_1_p_c_z_scene_node.html#a67be92d9316b6c88c8bfeec5ca72550d", null ],
      [ "clearVisitingZonesMap", "class_ogre_1_1_p_c_z_scene_node.html#aaf19143ee9ecc58fdba6b0acfcd12038", null ],
      [ "clearNodeFromVisitedZones", "class_ogre_1_1_p_c_z_scene_node.html#a2846e262c17f6b4f30f4d2af5bf1abc3", null ],
      [ "removeReferencesToZone", "class_ogre_1_1_p_c_z_scene_node.html#a4d81dda9d13d8f9dbd92af33c2b8fc7a", null ],
      [ "isVisitingZone", "class_ogre_1_1_p_c_z_scene_node.html#a04227c48035b82c2684e8a5a51f85e89", null ],
      [ "_addToRenderQueue", "class_ogre_1_1_p_c_z_scene_node.html#adba366cb94952a38d89233b1fe2659c4", null ],
      [ "savePrevPosition", "class_ogre_1_1_p_c_z_scene_node.html#a7e48f0050a417380da0cd7e9dbe0596d", null ],
      [ "getPrevPosition", "class_ogre_1_1_p_c_z_scene_node.html#ab5497bfbf1bbdae929c73b1a0d8d7dd6", null ],
      [ "getLastVisibleFrame", "class_ogre_1_1_p_c_z_scene_node.html#ac45c43303aa04a678eab5f7f513ed282", null ],
      [ "setLastVisibleFrame", "class_ogre_1_1_p_c_z_scene_node.html#a5ce4cd4c7c5a0bb486f2e5d4cc9218ff", null ],
      [ "setLastVisibleFromCamera", "class_ogre_1_1_p_c_z_scene_node.html#a6b59c3f19f8456ff0fae62c79c5a62b5", null ],
      [ "getLastVisibleFromCamera", "class_ogre_1_1_p_c_z_scene_node.html#aa78ecedb7b2f1f984f5edb1acee2e8a1", null ],
      [ "setZoneData", "class_ogre_1_1_p_c_z_scene_node.html#a9796c158ec5d31846a88189611e684a8", null ],
      [ "getZoneData", "class_ogre_1_1_p_c_z_scene_node.html#ad7f4d6b922c7e24cb03dae8c8c967c28", null ],
      [ "updateZoneData", "class_ogre_1_1_p_c_z_scene_node.html#ac73ae6322141c8e8216d3a9da389e79e", null ],
      [ "enable", "class_ogre_1_1_p_c_z_scene_node.html#a93841b613bcd99807c73e2a8662ff154", null ],
      [ "isEnabled", "class_ogre_1_1_p_c_z_scene_node.html#a5bc722be12f40702abc32fed51db4733", null ],
      [ "isMoved", "class_ogre_1_1_p_c_z_scene_node.html#a113768369e04425c6efc010711a51e26", null ],
      [ "setMoved", "class_ogre_1_1_p_c_z_scene_node.html#a8a4dac3a6a0f2efd55a0518672139200", null ]
    ] ],
    [ "Ogre::ZoneData", "class_ogre_1_1_zone_data.html", [
      [ "ZoneData", "class_ogre_1_1_zone_data.html#a5b430f410d3dced378f6922acceaeb4b", null ],
      [ "~ZoneData", "class_ogre_1_1_zone_data.html#aaf00ba34d0ae4ec4cdfebfdf3047f0c8", null ],
      [ "update", "class_ogre_1_1_zone_data.html#ab31896ee474a9f5039144ab5bc5013b2", null ],
      [ "mAssociatedZone", "class_ogre_1_1_zone_data.html#a0e85d178c29c65bc6cd9117f48770f4d", null ],
      [ "mAssociatedNode", "class_ogre_1_1_zone_data.html#a7275d372247b0354afafdfc47d7c2501", null ]
    ] ],
    [ "MAX_EXTRA_CULLING_PLANES", "group___p_c_z_scene_manager.html#gaf2200f97f28c856578a999b376ab4d16", null ],
    [ "Ogre::PCPlaneList", "group___p_c_z_scene_manager.html#ga07bdf350876770543f62b6b95b497180", null ],
    [ "Ogre::ZoneList", "group___p_c_z_scene_manager.html#gac4c591a87dc7186b252c1e2e6126d135", null ],
    [ "Ogre::ZoneMap", "group___p_c_z_scene_manager.html#ga526aa329710f833352e7fb4be64b199e", null ],
    [ "Ogre::PCZoneList", "group___p_c_z_scene_manager.html#ga903e29f61c83959d7aef4276afa88830", null ],
    [ "Ogre::PortalList", "group___p_c_z_scene_manager.html#gac5905c1abb8f5781e34a2d3429556d7b", null ],
    [ "Ogre::AntiPortalList", "group___p_c_z_scene_manager.html#ga1ef91416cb610243c95c0d2a93632477", null ],
    [ "Ogre::PortalBaseList", "group___p_c_z_scene_manager.html#gabf3685db9330ef8c24d6c52679b62e66", null ],
    [ "Ogre::NodeList", "group___p_c_z_scene_manager.html#ga95a02c492d84dad39eceaf52db8a61f1", null ],
    [ "Ogre::SceneNodeList", "group___p_c_z_scene_manager.html#ga05a24252386d9f480caf077f1d3917ef", null ],
    [ "Ogre::BoxList", "group___p_c_z_scene_manager.html#gaf6063d89781297c39d82561b964e4cf2", null ],
    [ "Ogre::ZoneDataMap", "group___p_c_z_scene_manager.html#gab554a1ca9b0e011f6c9c08cd24c3f4ea", null ]
];